For given Frequency Domain Operator S computes ratio S^{-1} at each frequency.
freqdom.inverse(S, n = NULL, Kconst = NULL, K = NULL)first spectral density
number of observations used for estimation - the precision of inversion is calculated using this parameter
constant for heuristic (as in reg.dim.est)
how many directions should be inverted (as in pseudoinverse)
Frequency Domain Operator object